spannertools.PianoPedalSpanner
==============================

.. abjad-lineage:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner

.. autoclass:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.append
      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.append_left
      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.components
      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.detach
      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.extend
      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.extend_left
      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.fracture
      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.fuse
      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.get_duration
      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.get_timespan
      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.index
      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.kind
      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.leaves
      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.pop
      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.pop_left
      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.style
      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.__contains__
      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.__copy__
      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.__eq__
      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.__format__
      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.__getitem__
      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.__len__
      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.__lt__
      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.__ne__
      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.__repr__

Bases
-----

- :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.leaves
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.kind
   :noindex:

.. autoattribute:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.style
   :noindex:

Methods
-------

.. automethod:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.append
   :noindex:

.. automethod:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.append_left
   :noindex:

.. automethod:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.detach
   :noindex:

.. automethod:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.extend
   :noindex:

.. automethod:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.extend_left
   :noindex:

.. automethod:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.fracture
   :noindex:

.. automethod:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.fuse
   :noindex:

.. automethod:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.get_duration
   :noindex:

.. automethod:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.get_timespan
   :noindex:

.. automethod:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.index
   :noindex:

.. automethod:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.pop
   :noindex:

.. automethod:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.pop_left
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.__copy__
   :noindex:

.. automethod:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.__format__
   :noindex:

.. automethod:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.__repr__
   :noindex:
